"""
:authors: Tigromag
:license: Apache license, Version 2.0, see LICENSE file
:copyright: (c) 2022 Tigromag
"""

from .convert_file import (convert_base, convert, )

__author__ = 'Tigromag'
__version__ = '1.0.0'
__email__ = 'tigromag010@gmail.com'
